<?php
if( !class_exists( 'f70LddSetup' ) ){
class f70LddSetup{
	
	public function __construct() {
		add_action( 'init', array( $this, 'create_posttype' ) );
		add_action( 'wp', array( $this, 'force_404_condition') );
		register_activation_hook( F70_LDD__PLUGIN_FILE, array( $this,'plugin_activate' ) );
		
		add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_style' ));
		
		add_filter( 'wp_sitemaps_posts_query_args', array( $this, 'excluding_sitemap' ), 10, 2 );
		add_filter( 'wp_sitemaps_post_types', array( $this, 'excluding_sitemap_by_posttype' ) );
	}
	
	public function plugin_activate() {
		flush_rewrite_rules();
		
		$this->make_db_table();
		$this->set_cookie_delete_key();
		$this->make_download_page();
		$this->create_posttype();
		
		//$this->make_sample_download_form();//ダウンロードフォームのサンプルを作る//未完成
	}
	
	public function make_download_page(){
		//ダウンロード用ページを作る
		$doit = false;
		if( $id = get_option( F70_LDD__DONWLOAD_PAGE_ID_OP ) ){
			if( $id == 0 ){
				$doit = true;
			}else{
				$page = get_post( get_option( F70_LDD__DONWLOAD_PAGE_ID_OP ) );
				if( !$page or ( $page->post_status !== 'publish' ) ){
					$doit = true;
				}
			}
		}else{
			$doit = true;
		}
		if( $doit ){
			global $wp_error;
			$id = wp_insert_post( self::download_page_setup(), $wp_error );
			update_option( F70_LDD__DONWLOAD_PAGE_ID_OP, $id );
		}
	}
	
	public function download_page_setup(){
		//ダウンロードページのなかみ
		
		//本文
		$body_sentence = __( 'Thank you for your interest in our service.', 'f70-lead-document-download' );//'ご関心をお寄せいただき、ありがとうございます。
		$body_sentence .= '<br>';
		$body_sentence .= __( 'Download the file on this page.', 'f70-lead-document-download' );//こちらからダウンロードしてください。
		
		$shortcode_block = 
		$body = '<!-- wp:paragraph --><p>' . $body_sentence . '</p><!-- /wp:paragraph -->'
			. '<!-- wp:shortcode -->[f70ldd_download]<!-- /wp:shortcode -->';
		
		$post = array(
			'ID'	=>	'',
			'post_content'	=>	$body,
			'post_name'	=>	F70_LDD__DONWLOAD_PAGE_SLUG,
			'post_title'	=>	__( 'Document download', 'f70-lead-document-download' ), //'ファイルダウンロード',
			'post_status'	=>	'publish',
			'post_type'	=>	'page',
			'comment_status'	=>	'closed',
		);
		return $post;
	}
	
	
	
	public function make_sample_download_form(){
		//ダウンロードフォームのサンプルを作る//未完成
		$doit = false;
		if( empty( get_option( F70_LDD__SAMPLE_FORM_ID ) ) ) {
			$doit = true;
		}
		if( $doit ){
			$post = array(
				'ID'	=>	'',
				//'post_content'	=>	$body,
				'post_name'	=>	'f70ldd_sample_form',
				'post_title'	=>	__( 'Sample Form', 'f70-lead-document-download' ),
				'post_status'	=>	'publish',
				'post_type'	=>	F70_LDD__POST_TYPE,
				'comment_status'	=>	'closed',
			);
			
			global $wp_error;
			$id = wp_insert_post( $post );
			if ( !empty( $id ) ) {
				update_option( F70_LDD__SAMPLE_FORM_ID, $id );
				
				//サンプル用のファイルを登録
				//media handle upload?? アップロード先ディレクトリの変更もいる、
				
				//カスタムフィールドをアプデート
				$post_meta = array(
					'f70ldd_attributes'	=>	'属性1::zokusei2::イラストレーター',
					'f70ldd_ng_attributes'	=>	'',
					'f70ldd_download_file_id_1'	=>	'',
					'f70ldd_download_thumbnail_id_1'	=>	'',
				);
				/*foreach ( $post_meta as $key => $val ) {
					update_post_meta( $id, $key, $val );
				}*/
			}
		}
	}
	
	
	
	
	public static function create_posttype() {
		//posttypeの作成
		register_post_type( F70_LDD__POST_TYPE,
			array(
				'labels' => array(
					'name'	=>	__( 'Download forms', 'f70-lead-document-download' ),
					'singular_name'	=>	__( 'Download form', 'f70-lead-document-download' )
				),
				'public'	=>	true,
				'exclude_from_search'	=>	true,
				'has_archive'	=>	true,
				'show_ui'	=>	true,
				'show_in_menu'	=>	'',
				'show_in_admin_bar'	=>	true,
				//'rewrite'	=>	array('slug'	=>	F70_LDD__POST_TYPE),
				'supports'	=>	array(
					'title',
					'custom-fields',
					//'thumbnail',
				),
			)
		);
	}
	
	//登録記録保存テーブルを作る
	public static function make_db_table(){
		global $wpdb;
		
		$charset_collate = $wpdb->get_charset_collate();
		
		$sql = "CREATE TABLE " . F70_LDD__DB_TABLE_NAME_LIST . " (
		 id mediumint(9) NOT NULL AUTO_INCREMENT,
		 time datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
		 email varchar(100) NOT NULL,
		 dlkey varchar(55) NOT NULL,
		 formid mediumint(9) NOT NULL,
		 count mediumint(3) NOT NULL,
		 UNIQUE KEY id (id)
		) $charset_collate;";
		
		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		dbDelta( $sql );
		
		//db version
		add_option( 'f70ldd_db_version', F70_LDD__DB_VERSION );
	}
	
	public static function set_cookie_delete_key() {
		//Cookie削除用のキー登録
		add_option( 'f70ldd_cookie_delete_key', f70LddFunctions::make_dlkey(16) );
	}
	
	
	public static function enqueue_style() {
		wp_enqueue_style( 'f70ldd', F70_LDD__PLUGIN_DIR_URL . '/assets/css/style.css' );
	}
	
	
	public function force_404_condition() {
		//フォーム設定ページは404する
		$att_page_ids = array();
		$the_query = new WP_Query( array( 'post_type' => F70_LDD__POST_TYPE ) );
		if ( $the_query->have_posts() ) {
			while ( $the_query->have_posts() ) {
				$the_query->the_post();
				$atts = f70LddFunctions::get_form_settings( $the_query->post->ID );
				for( $i=1; $i<=F70_LDD__FILE_SETS; $i++ ){
					if( !empty( $atts[ 'download_file_id_' . $i ] ) ) {
						$att_page_ids[] = $atts[ 'download_file_id_' . $i ];
					}
				}
			}
			wp_reset_postdata();
		}
		
		global $wp_query;
		if ( ! is_user_logged_in() ) {
			if( is_single( $att_page_ids ) ){
				self::force_404();
			}
		}
	}
	
	public function force_404() {
		status_header( 404 );
		nocache_headers();
		include( get_query_template( '404' ) );
		die();
	}
	
	
	
	public static function excluding_sitemap( $args, $post_type ) {
		//サイトマップへの搭載を避ける
		$args['post__not_in'] = isset( $args['post__not_in'] ) ? $args['post__not_in'] : array();
		
		////ダウンロードページ
		if( $id = get_option( F70_LDD__DONWLOAD_PAGE_ID_OP ) ){
			if( !empty( $id ) && !empty( get_post( $id ) ) ) {
				$args[ 'post__not_in' ][] = $id;
			}
		}
		
		return $args;
	}
	public static function excluding_sitemap_by_posttype( $post_types ) {
		//サイトマップへの搭載を避ける
		////設定ページ
		if ( !empty( $post_types[ F70_LDD__POST_TYPE ] ) ) {
			unset( $post_types[ F70_LDD__POST_TYPE ] );
		}
		return $post_types;
	}
	
//----
}
}
?>